@@ -187,24 +187,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def CreateStandaloneGateway(
-            self,
-            request: models.CreateStandaloneGatewayRequest,
-            opts: Dict = None,
-    ) -> models.CreateStandaloneGatewayResponse:
-        """
-        本接口（CreateStandaloneGateway）用于创建独立网关。
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "CreateStandaloneGateway"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.CreateStandaloneGatewayResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def CreateStaticStore(
             self,
             request: models.CreateStaticStoreRequest,
@@ -223,42 +205,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def CreateWxCloudBaseRunEnv(
-            self,
-            request: models.CreateWxCloudBaseRunEnvRequest,
-            opts: Dict = None,
-    ) -> models.CreateWxCloudBaseRunEnvResponse:
-        """
-        创建微信云托管
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "CreateWxCloudBaseRunEnv"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.CreateWxCloudBaseRunEnvResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def CreateWxCloudBaseRunServerDBCluster(
-            self,
-            request: models.CreateWxCloudBaseRunServerDBClusterRequest,
-            opts: Dict = None,
-    ) -> models.CreateWxCloudBaseRunServerDBClusterResponse:
-        """
-        开通微信云托管MySQL数据库服务
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "CreateWxCloudBaseRunServerDBCluster"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.CreateWxCloudBaseRunServerDBClusterResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DeleteCloudBaseProjectLatestVersion(
             self,
             request: models.DeleteCloudBaseProjectLatestVersionRequest,
@@ -295,24 +241,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DeleteEndUser(
-            self,
-            request: models.DeleteEndUserRequest,
-            opts: Dict = None,
-    ) -> models.DeleteEndUserResponse:
-        """
-        删除终端用户
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DeleteEndUser"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DeleteEndUserResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DeleteGatewayVersion(
             self,
             request: models.DeleteGatewayVersionRequest,
@@ -493,96 +421,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DescribeCloudBaseRunAllVpcs(
-            self,
-            request: models.DescribeCloudBaseRunAllVpcsRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunAllVpcsResponse:
-        """
-        查询环境下所有的vpc列表
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunAllVpcs"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunAllVpcsResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeCloudBaseRunConfForGateWay(
-            self,
-            request: models.DescribeCloudBaseRunConfForGateWayRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunConfForGateWayResponse:
-        """
-        独立网关中拉取云托管服务对应的配置信息
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunConfForGateWay"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunConfForGateWayResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeCloudBaseRunOneClickTaskExternal(
-            self,
-            request: models.DescribeCloudBaseRunOneClickTaskExternalRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunOneClickTaskExternalResponse:
-        """
-        查询一键部署任务 （特定接口：外部查询使用）
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunOneClickTaskExternal"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunOneClickTaskExternalResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeCloudBaseRunOperationTypes(
-            self,
-            request: models.DescribeCloudBaseRunOperationTypesRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunOperationTypesResponse:
-        """
-        查询服务、版本和操作类型
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunOperationTypes"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunOperationTypesResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeCloudBaseRunPodList(
-            self,
-            request: models.DescribeCloudBaseRunPodListRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunPodListResponse:
-        """
-        查询云托管服务版本容器列表
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunPodList"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunPodListResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DescribeCloudBaseRunResource(
             self,
             request: models.DescribeCloudBaseRunResourceRequest,
@@ -637,24 +475,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DescribeCloudBaseRunServerDomainName(
-            self,
-            request: models.DescribeCloudBaseRunServerDomainNameRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunServerDomainNameResponse:
-        """
-        查询微信云托管服务域名
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunServerDomainName"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunServerDomainNameResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DescribeCloudBaseRunServerVersion(
             self,
             request: models.DescribeCloudBaseRunServerVersionRequest,
@@ -691,24 +511,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DescribeCloudBaseRunVersionRsByCondition(
-            self,
-            request: models.DescribeCloudBaseRunVersionRsByConditionRequest,
-            opts: Dict = None,
-    ) -> models.DescribeCloudBaseRunVersionRsByConditionResponse:
-        """
-        DescribeCloudBaseRunVersionRsByCondition 获取云托管详情
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeCloudBaseRunVersionRsByCondition"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeCloudBaseRunVersionRsByConditionResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DescribeCloudBaseRunVersionSnapshot(
             self,
             request: models.DescribeCloudBaseRunVersionSnapshotRequest,
@@ -781,60 +583,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DescribeEndUserLoginStatistic(
-            self,
-            request: models.DescribeEndUserLoginStatisticRequest,
-            opts: Dict = None,
-    ) -> models.DescribeEndUserLoginStatisticResponse:
-        """
-        获取环境终端用户新增与登录信息
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeEndUserLoginStatistic"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeEndUserLoginStatisticResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeEndUserStatistic(
-            self,
-            request: models.DescribeEndUserStatisticRequest,
-            opts: Dict = None,
-    ) -> models.DescribeEndUserStatisticResponse:
-        """
-        获取终端用户总量与平台分布情况
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeEndUserStatistic"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeEndUserStatisticResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeEndUsers(
-            self,
-            request: models.DescribeEndUsersRequest,
-            opts: Dict = None,
-    ) -> models.DescribeEndUsersResponse:
-        """
-        获取终端用户列表
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeEndUsers"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeEndUsersResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DescribeEnvDealRegion(
             self,
             request: models.DescribeEnvDealRegionRequest,
@@ -1127,42 +875,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DescribeStandaloneGateway(
-            self,
-            request: models.DescribeStandaloneGatewayRequest,
-            opts: Dict = None,
-    ) -> models.DescribeStandaloneGatewayResponse:
-        """
-        本接口（DescribeStandaloneGateway）查询小租户网关套餐信息。
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeStandaloneGateway"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeStandaloneGatewayResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeStandaloneGatewayPackage(
-            self,
-            request: models.DescribeStandaloneGatewayPackageRequest,
-            opts: Dict = None,
-    ) -> models.DescribeStandaloneGatewayPackageResponse:
-        """
-        本接口（DescribeStandaloneGatewayPackage）用于查询小租户网关套餐信息。
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeStandaloneGatewayPackage"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeStandaloneGatewayPackageResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DescribeUserActivityInfo(
             self,
             request: models.DescribeUserActivityInfoRequest,
@@ -1181,42 +893,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DescribeWxCloudBaseRunEnvs(
-            self,
-            request: models.DescribeWxCloudBaseRunEnvsRequest,
-            opts: Dict = None,
-    ) -> models.DescribeWxCloudBaseRunEnvsResponse:
-        """
-        查询微信云托管环境信息
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeWxCloudBaseRunEnvs"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeWxCloudBaseRunEnvsResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def DescribeWxCloudBaseRunSubNets(
-            self,
-            request: models.DescribeWxCloudBaseRunSubNetsRequest,
-            opts: Dict = None,
-    ) -> models.DescribeWxCloudBaseRunSubNetsResponse:
-        """
-        查询微信云托管子网
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DescribeWxCloudBaseRunSubNets"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DescribeWxCloudBaseRunSubNetsResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DescribeWxGatewayRoutes(
             self,
             request: models.DescribeWxGatewayRoutesRequest,
@@ -1271,24 +947,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def DestroyStandaloneGateway(
-            self,
-            request: models.DestroyStandaloneGatewayRequest,
-            opts: Dict = None,
-    ) -> models.DestroyStandaloneGatewayResponse:
-        """
-        本接口（DestroyStandaloneGateway）用于销毁小租户网关。
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "DestroyStandaloneGateway"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.DestroyStandaloneGatewayResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def DestroyStaticStore(
             self,
             request: models.DestroyStaticStoreRequest,
@@ -1451,24 +1109,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def ModifyEndUser(
-            self,
-            request: models.ModifyEndUserRequest,
-            opts: Dict = None,
-    ) -> models.ModifyEndUserResponse:
-        """
-        管理终端用户
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "ModifyEndUser"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.ModifyEndUserResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def ModifyEnv(
             self,
             request: models.ModifyEnvRequest,
@@ -1541,24 +1181,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def RollUpdateCloudBaseRunServerVersion(
-            self,
-            request: models.RollUpdateCloudBaseRunServerVersionRequest,
-            opts: Dict = None,
-    ) -> models.RollUpdateCloudBaseRunServerVersionResponse:
-        """
-        针对特定的版本，进行滚动更新
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "RollUpdateCloudBaseRunServerVersion"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.RollUpdateCloudBaseRunServerVersionResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def SearchClsLog(
             self,
             request: models.SearchClsLogRequest,
@@ -1577,42 +1199,6 @@ class TcbClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
-    async def TurnOffStandaloneGateway(
-            self,
-            request: models.TurnOffStandaloneGatewayRequest,
-            opts: Dict = None,
-    ) -> models.TurnOffStandaloneGatewayResponse:
-        """
-        本接口（TurnOffStandaloneGateway）用于关闭小租户网关。
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "TurnOffStandaloneGateway"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.TurnOffStandaloneGatewayResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
-    async def TurnOnStandaloneGateway(
-            self,
-            request: models.TurnOnStandaloneGatewayRequest,
-            opts: Dict = None,
-    ) -> models.TurnOnStandaloneGatewayResponse:
-        """
-        本接口（TurnOnStandaloneGateway）用于开启小租户网关。
-        """
-        
-        kwargs = {}
-        kwargs["action"] = "TurnOnStandaloneGateway"
-        kwargs["params"] = request._serialize()
-        kwargs["resp_cls"] = models.TurnOnStandaloneGatewayResponse
-        kwargs["headers"] = request.headers
-        kwargs["opts"] = opts or {}
-        
-        return await self.call_and_deserialize(**kwargs)
-        
     async def UnfreezeCloudBaseRunServers(
             self,
             request: models.UnfreezeCloudBaseRunServersRequest,
